==> com.liferay.app.builder.web-1.0.2.jar: org/apache/jsp/layout/view_jsp.java <==
package org.apache.jsp.layout;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import com.liferay.portal.kernel.portlet.PortletProvider;
import com.liferay.portal.kernel.util.HtmlUtil;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.PortalUtil;
import com.liferay.portal.kernel.webserver.WebServerServletTokenUtil;

public final class view_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List<String> _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList<String>(1);
    _jspx_dependants.add("/layout/init.jsp");
  }

  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1theme_defineObjects_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1util_html$1top;

  private org.glassfish.jsp.api.ResourceInjector _jspx_resourceInjector;

  public java.util.List<String> getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _jspx_tagPool_liferay$1theme_defineObjects_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1util_html$1top = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
  }

  public void _jspDestroy() {
    _jspx_tagPool_liferay$1theme_defineObjects_nobody.release();
    _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.release();
    _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.release();
    _jspx_tagPool_liferay$1util_html$1top.release();
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;

    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;
      _jspx_resourceInjector = (org.glassfish.jsp.api.ResourceInjector) application.getAttribute("com.sun.appserv.jsp.resource.injector");

      out.write('\n');
      out.write('\n');
      out.write("\n\n\n\n\n\n");
      //  liferay-theme:defineObjects
      com.liferay.taglib.theme.DefineObjectsTag _jspx_th_liferay$1theme_defineObjects_0 = (com.liferay.taglib.theme.DefineObjectsTag) _jspx_tagPool_liferay$1theme_defineObjects_nobody.get(com.liferay.taglib.theme.DefineObjectsTag.class);
      _jspx_th_liferay$1theme_defineObjects_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1theme_defineObjects_0.setParent(null);
      int _jspx_eval_liferay$1theme_defineObjects_0 = _jspx_th_liferay$1theme_defineObjects_0.doStartTag();
      if (_jspx_th_liferay$1theme_defineObjects_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1theme_defineObjects_nobody.reuse(_jspx_th_liferay$1theme_defineObjects_0);
        return;
      }
      _jspx_tagPool_liferay$1theme_defineObjects_nobody.reuse(_jspx_th_liferay$1theme_defineObjects_0);
      com.liferay.portal.kernel.theme.ThemeDisplay themeDisplay = null;
      com.liferay.portal.kernel.model.Company company = null;
      com.liferay.portal.kernel.model.Account account = null;
      com.liferay.portal.kernel.model.User user = null;
      com.liferay.portal.kernel.model.User realUser = null;
      com.liferay.portal.kernel.model.Contact contact = null;
      com.liferay.portal.kernel.model.Layout layout = null;
      java.util.List layouts = null;
      java.lang.Long plid = null;
      com.liferay.portal.kernel.model.LayoutTypePortlet layoutTypePortlet = null;
      java.lang.Long scopeGroupId = null;
      com.liferay.portal.kernel.security.permission.PermissionChecker permissionChecker = null;
      java.util.Locale locale = null;
      java.util.TimeZone timeZone = null;
      com.liferay.portal.kernel.model.Theme theme = null;
      com.liferay.portal.kernel.model.ColorScheme colorScheme = null;
      com.liferay.portal.kernel.theme.PortletDisplay portletDisplay = null;
      java.lang.Long portletGroupId = null;
      themeDisplay = (com.liferay.portal.kernel.theme.ThemeDisplay) _jspx_page_context.findAttribute("themeDisplay");
      company = (com.liferay.portal.kernel.model.Company) _jspx_page_context.findAttribute("company");
      account = (com.liferay.portal.kernel.model.Account) _jspx_page_context.findAttribute("account");
      user = (com.liferay.portal.kernel.model.User) _jspx_page_context.findAttribute("user");
      realUser = (com.liferay.portal.kernel.model.User) _jspx_page_context.findAttribute("realUser");
      contact = (com.liferay.portal.kernel.model.Contact) _jspx_page_context.findAttribute("contact");
      layout = (com.liferay.portal.kernel.model.Layout) _jspx_page_context.findAttribute("layout");
      layouts = (java.util.List) _jspx_page_context.findAttribute("layouts");
      plid = (java.lang.Long) _jspx_page_context.findAttribute("plid");
      layoutTypePortlet = (com.liferay.portal.kernel.model.LayoutTypePortlet) _jspx_page_context.findAttribute("layoutTypePortlet");
      scopeGroupId = (java.lang.Long) _jspx_page_context.findAttribute("scopeGroupId");
      permissionChecker = (com.liferay.portal.kernel.security.permission.PermissionChecker) _jspx_page_context.findAttribute("permissionChecker");
      locale = (java.util.Locale) _jspx_page_context.findAttribute("locale");
      timeZone = (java.util.TimeZone) _jspx_page_context.findAttribute("timeZone");
      theme = (com.liferay.portal.kernel.model.Theme) _jspx_page_context.findAttribute("theme");
      colorScheme = (com.liferay.portal.kernel.model.ColorScheme) _jspx_page_context.findAttribute("colorScheme");
      portletDisplay = (com.liferay.portal.kernel.theme.PortletDisplay) _jspx_page_context.findAttribute("portletDisplay");
      portletGroupId = (java.lang.Long) _jspx_page_context.findAttribute("portletGroupId");
      out.write('\n');
      out.write('\n');
      if (_jspx_meth_liferay$1util_html$1top_0(_jspx_page_context))
        return;
      out.write('\n');
      out.write('\n');

String appName = ParamUtil.getString(request, "appName");

String portletName = ParamUtil.getString(request, "portletName");

String editEntryCssClass = "";

String mvcPath = ParamUtil.getString(request, PortalUtil.getPortletNamespace(portletName) + "mvcPath");

if (mvcPath.startsWith("/edit_entry.jsp")) {
	editEntryCssClass = "edit-entry";
}

      out.write("\n\n<div class=\"app-builder-standalone\">\n\t<header class=\"app-builder-standalone-header\">\n\t\t<div class=\"container p-0\">\n\t\t\t<div class=\"app-builder-standalone-menu autofit-row\">\n\t\t\t\t<div class=\"autofit-col autofit-col-expand\">\n\t\t\t\t\t<a class=\"company-link\" href=\"");
      out.print( PortalUtil.addPreservedParameters(themeDisplay, themeDisplay.getURLPortal(), false, true) );
      out.write("\">\n\t\t\t\t\t\t<span class=\"company-details text-truncate\">\n\t\t\t\t\t\t\t<img alt=\"\" class=\"company-logo\" src=\"");
      out.print( themeDisplay.getPathImage() + "/company_logo?img_id=" + company.getLogoId() + "&t=" + WebServerServletTokenUtil.getToken(company.getLogoId()) );
      out.write("\" />\n\n\t\t\t\t\t\t\t<span class=\"company-name\">");
      out.print( HtmlUtil.escape(company.getName()) );
      out.write("</span>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t</a>\n\t\t\t\t</div>\n\n\t\t\t\t<div class=\"col text-right\">\n\t\t\t\t\t");
      //  liferay-portlet:runtime
      com.liferay.taglib.portletext.RuntimeTag _jspx_th_liferay$1portlet_runtime_0 = (com.liferay.taglib.portletext.RuntimeTag) _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.get(com.liferay.taglib.portletext.RuntimeTag.class);
      _jspx_th_liferay$1portlet_runtime_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1portlet_runtime_0.setParent(null);
      _jspx_th_liferay$1portlet_runtime_0.setPortletProviderAction( PortletProvider.Action.VIEW );
      _jspx_th_liferay$1portlet_runtime_0.setPortletProviderClassName("com.liferay.admin.kernel.util.PortalUserPersonalBarApplicationType$UserPersonalBar");
      int _jspx_eval_liferay$1portlet_runtime_0 = _jspx_th_liferay$1portlet_runtime_0.doStartTag();
      if (_jspx_th_liferay$1portlet_runtime_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.reuse(_jspx_th_liferay$1portlet_runtime_0);
        return;
      }
      _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.reuse(_jspx_th_liferay$1portlet_runtime_0);
      out.write("\n\t\t\t\t</div>\n\t\t\t</div>\n\n\t\t\t<h1 class=\"app-builder-standalone-name ");
      out.print( editEntryCssClass );
      out.write('"');
      out.write('>');
      out.print( HtmlUtil.escape(appName) );
      out.write("</h1>\n\t\t</div>\n\t</header>\n\n\t<div class=\"app-builder-standalone-content container ");
      out.print( editEntryCssClass );
      out.write(" sheet\">\n\t\t");
      //  liferay-portlet:runtime
      com.liferay.taglib.portletext.RuntimeTag _jspx_th_liferay$1portlet_runtime_1 = (com.liferay.taglib.portletext.RuntimeTag) _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.get(com.liferay.taglib.portletext.RuntimeTag.class);
      _jspx_th_liferay$1portlet_runtime_1.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1portlet_runtime_1.setParent(null);
      _jspx_th_liferay$1portlet_runtime_1.setPortletName( portletName );
      int _jspx_eval_liferay$1portlet_runtime_1 = _jspx_th_liferay$1portlet_runtime_1.doStartTag();
      if (_jspx_th_liferay$1portlet_runtime_1.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_1);
        return;
      }
      _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_1);
      out.write("\n\t</div>\n</div>");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
        else throw new ServletException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }

  private boolean _jspx_meth_liferay$1util_html$1top_0(PageContext _jspx_page_context)
          throws Throwable {
    PageContext pageContext = _jspx_page_context;
    JspWriter out = _jspx_page_context.getOut();
    //  liferay-util:html-top
    com.liferay.taglib.util.HtmlTopTag _jspx_th_liferay$1util_html$1top_0 = (com.liferay.taglib.util.HtmlTopTag) _jspx_tagPool_liferay$1util_html$1top.get(com.liferay.taglib.util.HtmlTopTag.class);
    _jspx_th_liferay$1util_html$1top_0.setPageContext(_jspx_page_context);
    _jspx_th_liferay$1util_html$1top_0.setParent(null);
    int _jspx_eval_liferay$1util_html$1top_0 = _jspx_th_liferay$1util_html$1top_0.doStartTag();
    if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.SKIP_BODY) {
      if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.EVAL_BODY_INCLUDE) {
        out = _jspx_page_context.pushBody();
        _jspx_th_liferay$1util_html$1top_0.setBodyContent((javax.servlet.jsp.tagext.BodyContent) out);
        _jspx_th_liferay$1util_html$1top_0.doInitBody();
      }
      do {
        out.write("\n\t<meta content=\"initial-scale=1.0, width=device-width\" name=\"viewport\" />\n");
        int evalDoAfterBody = _jspx_th_liferay$1util_html$1top_0.doAfterBody();
        if (evalDoAfterBody != javax.servlet.jsp.tagext.BodyTag.EVAL_BODY_AGAIN)
          break;
      } while (true);
      if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.EVAL_BODY_INCLUDE)
        out = _jspx_page_context.popBody();
    }
    if (_jspx_th_liferay$1util_html$1top_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
      _jspx_tagPool_liferay$1util_html$1top.reuse(_jspx_th_liferay$1util_html$1top_0);
      return true;
    }
    _jspx_tagPool_liferay$1util_html$1top.reuse(_jspx_th_liferay$1util_html$1top_0);
    return false;
  }
}

==> com.liferay.app.builder.web-1.0.18.jar: org/apache/jsp/layout/view_jsp.java <==
package org.apache.jsp.layout;

import javax.servlet.*;
import javax.servlet.http.*;
import javax.servlet.jsp.*;
import com.liferay.portal.kernel.portlet.PortletProvider;
import com.liferay.portal.kernel.util.HtmlUtil;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.PortalUtil;
import com.liferay.portal.kernel.util.PortletKeys;
import com.liferay.portal.kernel.webserver.WebServerServletTokenUtil;

public final class view_jsp extends org.apache.jasper.runtime.HttpJspBase
    implements org.apache.jasper.runtime.JspSourceDependent {

  private static final JspFactory _jspxFactory = JspFactory.getDefaultFactory();

  private static java.util.List<String> _jspx_dependants;

  static {
    _jspx_dependants = new java.util.ArrayList<String>(1);
    _jspx_dependants.add("/layout/init.jsp");
  }

  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1theme_defineObjects_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody;
  private org.apache.jasper.runtime.TagHandlerPool _jspx_tagPool_liferay$1util_html$1top;

  private org.glassfish.jsp.api.ResourceInjector _jspx_resourceInjector;

  public java.util.List<String> getDependants() {
    return _jspx_dependants;
  }

  public void _jspInit() {
    _jspx_tagPool_liferay$1theme_defineObjects_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
    _jspx_tagPool_liferay$1util_html$1top = org.apache.jasper.runtime.TagHandlerPool.getTagHandlerPool(getServletConfig());
  }

  public void _jspDestroy() {
    _jspx_tagPool_liferay$1theme_defineObjects_nobody.release();
    _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.release();
    _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.release();
    _jspx_tagPool_liferay$1util_html$1top.release();
  }

  public void _jspService(HttpServletRequest request, HttpServletResponse response)
        throws java.io.IOException, ServletException {

    PageContext pageContext = null;
    HttpSession session = null;
    ServletContext application = null;
    ServletConfig config = null;
    JspWriter out = null;
    Object page = this;
    JspWriter _jspx_out = null;
    PageContext _jspx_page_context = null;

    try {
      response.setContentType("text/html");
      pageContext = _jspxFactory.getPageContext(this, request, response,
      			null, true, 8192, true);
      _jspx_page_context = pageContext;
      application = pageContext.getServletContext();
      config = pageContext.getServletConfig();
      session = pageContext.getSession();
      out = pageContext.getOut();
      _jspx_out = out;
      _jspx_resourceInjector = (org.glassfish.jsp.api.ResourceInjector) application.getAttribute("com.sun.appserv.jsp.resource.injector");

      out.write('\n');
      out.write('\n');
      out.write("\n\n\n\n\n\n");
      //  liferay-theme:defineObjects
      com.liferay.taglib.theme.DefineObjectsTag _jspx_th_liferay$1theme_defineObjects_0 = (com.liferay.taglib.theme.DefineObjectsTag) _jspx_tagPool_liferay$1theme_defineObjects_nobody.get(com.liferay.taglib.theme.DefineObjectsTag.class);
      _jspx_th_liferay$1theme_defineObjects_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1theme_defineObjects_0.setParent(null);
      int _jspx_eval_liferay$1theme_defineObjects_0 = _jspx_th_liferay$1theme_defineObjects_0.doStartTag();
      if (_jspx_th_liferay$1theme_defineObjects_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1theme_defineObjects_nobody.reuse(_jspx_th_liferay$1theme_defineObjects_0);
        return;
      }
      _jspx_tagPool_liferay$1theme_defineObjects_nobody.reuse(_jspx_th_liferay$1theme_defineObjects_0);
      com.liferay.portal.kernel.theme.ThemeDisplay themeDisplay = null;
      com.liferay.portal.kernel.model.Company company = null;
      com.liferay.portal.kernel.model.Account account = null;
      com.liferay.portal.kernel.model.User user = null;
      com.liferay.portal.kernel.model.User realUser = null;
      com.liferay.portal.kernel.model.Contact contact = null;
      com.liferay.portal.kernel.model.Layout layout = null;
      java.util.List layouts = null;
      java.lang.Long plid = null;
      com.liferay.portal.kernel.model.LayoutTypePortlet layoutTypePortlet = null;
      java.lang.Long scopeGroupId = null;
      com.liferay.portal.kernel.security.permission.PermissionChecker permissionChecker = null;
      java.util.Locale locale = null;
      java.util.TimeZone timeZone = null;
      com.liferay.portal.kernel.model.Theme theme = null;
      com.liferay.portal.kernel.model.ColorScheme colorScheme = null;
      com.liferay.portal.kernel.theme.PortletDisplay portletDisplay = null;
      java.lang.Long portletGroupId = null;
      themeDisplay = (com.liferay.portal.kernel.theme.ThemeDisplay) _jspx_page_context.findAttribute("themeDisplay");
      company = (com.liferay.portal.kernel.model.Company) _jspx_page_context.findAttribute("company");
      account = (com.liferay.portal.kernel.model.Account) _jspx_page_context.findAttribute("account");
      user = (com.liferay.portal.kernel.model.User) _jspx_page_context.findAttribute("user");
      realUser = (com.liferay.portal.kernel.model.User) _jspx_page_context.findAttribute("realUser");
      contact = (com.liferay.portal.kernel.model.Contact) _jspx_page_context.findAttribute("contact");
      layout = (com.liferay.portal.kernel.model.Layout) _jspx_page_context.findAttribute("layout");
      layouts = (java.util.List) _jspx_page_context.findAttribute("layouts");
      plid = (java.lang.Long) _jspx_page_context.findAttribute("plid");
      layoutTypePortlet = (com.liferay.portal.kernel.model.LayoutTypePortlet) _jspx_page_context.findAttribute("layoutTypePortlet");
      scopeGroupId = (java.lang.Long) _jspx_page_context.findAttribute("scopeGroupId");
      permissionChecker = (com.liferay.portal.kernel.security.permission.PermissionChecker) _jspx_page_context.findAttribute("permissionChecker");
      locale = (java.util.Locale) _jspx_page_context.findAttribute("locale");
      timeZone = (java.util.TimeZone) _jspx_page_context.findAttribute("timeZone");
      theme = (com.liferay.portal.kernel.model.Theme) _jspx_page_context.findAttribute("theme");
      colorScheme = (com.liferay.portal.kernel.model.ColorScheme) _jspx_page_context.findAttribute("colorScheme");
      portletDisplay = (com.liferay.portal.kernel.theme.PortletDisplay) _jspx_page_context.findAttribute("portletDisplay");
      portletGroupId = (java.lang.Long) _jspx_page_context.findAttribute("portletGroupId");
      out.write('\n');
      out.write('\n');
      if (_jspx_meth_liferay$1util_html$1top_0(_jspx_page_context))
        return;
      out.write('\n');
      out.write('\n');

String appName = ParamUtil.getString(request, "appName");

String portletName = ParamUtil.getString(request, "portletName");

String editEntryCssClass = "";

String mvcPath = ParamUtil.getString(request, PortalUtil.getPortletNamespace(portletName) + "mvcPath");

if (mvcPath.startsWith("/edit_entry.jsp")) {
	editEntryCssClass = "edit-entry";
}

      out.write("\n\n<div class=\"app-builder-standalone\">\n\t<header class=\"app-builder-standalone-header\">\n\t\t<div class=\"container p-0\">\n\t\t\t<div class=\"app-builder-standalone-menu autofit-row\">\n\t\t\t\t<div class=\"autofit-col autofit-col-expand\">\n\t\t\t\t\t<a class=\"company-link\" href=\"");
      out.print( PortalUtil.addPreservedParameters(themeDisplay, themeDisplay.getURLPortal(), false, true) );
      out.write("\">\n\t\t\t\t\t\t<span class=\"company-details text-truncate\">\n\t\t\t\t\t\t\t<img alt=\"\" class=\"company-logo\" src=\"");
      out.print( themeDisplay.getPathImage() + "/company_logo?img_id=" + company.getLogoId() + "&t=" + WebServerServletTokenUtil.getToken(company.getLogoId()) );
      out.write("\" />\n\n\t\t\t\t\t\t\t<span class=\"company-name\">");
      out.print( HtmlUtil.escape(company.getName()) );
      out.write("</span>\n\t\t\t\t\t\t</span>\n\t\t\t\t\t</a>\n\t\t\t\t</div>\n\n\t\t\t\t<div style=\"display: none;\">\n\t\t\t\t\t");
      //  liferay-portlet:runtime
      com.liferay.taglib.portletext.RuntimeTag _jspx_th_liferay$1portlet_runtime_0 = (com.liferay.taglib.portletext.RuntimeTag) _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.get(com.liferay.taglib.portletext.RuntimeTag.class);
      _jspx_th_liferay$1portlet_runtime_0.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1portlet_runtime_0.setParent(null);
      _jspx_th_liferay$1portlet_runtime_0.setPortletName( PortletKeys.LOGIN );
      int _jspx_eval_liferay$1portlet_runtime_0 = _jspx_th_liferay$1portlet_runtime_0.doStartTag();
      if (_jspx_th_liferay$1portlet_runtime_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_0);
        return;
      }
      _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_0);
      out.write("\n\t\t\t\t</div>\n\n\t\t\t\t<div class=\"autofit-col text-right\">\n\t\t\t\t\t");
      //  liferay-portlet:runtime
      com.liferay.taglib.portletext.RuntimeTag _jspx_th_liferay$1portlet_runtime_1 = (com.liferay.taglib.portletext.RuntimeTag) _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.get(com.liferay.taglib.portletext.RuntimeTag.class);
      _jspx_th_liferay$1portlet_runtime_1.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1portlet_runtime_1.setParent(null);
      _jspx_th_liferay$1portlet_runtime_1.setPortletProviderAction( PortletProvider.Action.VIEW );
      _jspx_th_liferay$1portlet_runtime_1.setPortletProviderClassName("com.liferay.admin.kernel.util.PortalUserPersonalBarApplicationType$UserPersonalBar");
      int _jspx_eval_liferay$1portlet_runtime_1 = _jspx_th_liferay$1portlet_runtime_1.doStartTag();
      if (_jspx_th_liferay$1portlet_runtime_1.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.reuse(_jspx_th_liferay$1portlet_runtime_1);
        return;
      }
      _jspx_tagPool_liferay$1portlet_runtime_portletProviderClassName_portletProviderAction_nobody.reuse(_jspx_th_liferay$1portlet_runtime_1);
      out.write("\n\t\t\t\t</div>\n\t\t\t</div>\n\n\t\t\t<h1 class=\"app-builder-standalone-name ");
      out.print( editEntryCssClass );
      out.write('"');
      out.write('>');
      out.print( HtmlUtil.escape(appName) );
      out.write("</h1>\n\t\t</div>\n\t</header>\n\n\t<div class=\"app-builder-standalone-content container ");
      out.print( editEntryCssClass );
      out.write(" sheet\">\n\t\t");
      //  liferay-portlet:runtime
      com.liferay.taglib.portletext.RuntimeTag _jspx_th_liferay$1portlet_runtime_2 = (com.liferay.taglib.portletext.RuntimeTag) _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.get(com.liferay.taglib.portletext.RuntimeTag.class);
      _jspx_th_liferay$1portlet_runtime_2.setPageContext(_jspx_page_context);
      _jspx_th_liferay$1portlet_runtime_2.setParent(null);
      _jspx_th_liferay$1portlet_runtime_2.setPortletName( portletName );
      int _jspx_eval_liferay$1portlet_runtime_2 = _jspx_th_liferay$1portlet_runtime_2.doStartTag();
      if (_jspx_th_liferay$1portlet_runtime_2.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
        _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_2);
        return;
      }
      _jspx_tagPool_liferay$1portlet_runtime_portletName_nobody.reuse(_jspx_th_liferay$1portlet_runtime_2);
      out.write("\n\t</div>\n</div>");
    } catch (Throwable t) {
      if (!(t instanceof SkipPageException)){
        out = _jspx_out;
        if (out != null && out.getBufferSize() != 0)
          out.clearBuffer();
        if (_jspx_page_context != null) _jspx_page_context.handlePageException(t);
        else throw new ServletException(t);
      }
    } finally {
      _jspxFactory.releasePageContext(_jspx_page_context);
    }
  }

  private boolean _jspx_meth_liferay$1util_html$1top_0(PageContext _jspx_page_context)
          throws Throwable {
    PageContext pageContext = _jspx_page_context;
    JspWriter out = _jspx_page_context.getOut();
    //  liferay-util:html-top
    com.liferay.taglib.util.HtmlTopTag _jspx_th_liferay$1util_html$1top_0 = (com.liferay.taglib.util.HtmlTopTag) _jspx_tagPool_liferay$1util_html$1top.get(com.liferay.taglib.util.HtmlTopTag.class);
    _jspx_th_liferay$1util_html$1top_0.setPageContext(_jspx_page_context);
    _jspx_th_liferay$1util_html$1top_0.setParent(null);
    int _jspx_eval_liferay$1util_html$1top_0 = _jspx_th_liferay$1util_html$1top_0.doStartTag();
    if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.SKIP_BODY) {
      if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.EVAL_BODY_INCLUDE) {
        out = _jspx_page_context.pushBody();
        _jspx_th_liferay$1util_html$1top_0.setBodyContent((javax.servlet.jsp.tagext.BodyContent) out);
        _jspx_th_liferay$1util_html$1top_0.doInitBody();
      }
      do {
        out.write("\n\t<meta content=\"initial-scale=1.0, width=device-width\" name=\"viewport\" />\n");
        int evalDoAfterBody = _jspx_th_liferay$1util_html$1top_0.doAfterBody();
        if (evalDoAfterBody != javax.servlet.jsp.tagext.BodyTag.EVAL_BODY_AGAIN)
          break;
      } while (true);
      if (_jspx_eval_liferay$1util_html$1top_0 != javax.servlet.jsp.tagext.Tag.EVAL_BODY_INCLUDE)
        out = _jspx_page_context.popBody();
    }
    if (_jspx_th_liferay$1util_html$1top_0.doEndTag() == javax.servlet.jsp.tagext.Tag.SKIP_PAGE) {
      _jspx_tagPool_liferay$1util_html$1top.reuse(_jspx_th_liferay$1util_html$1top_0);
      return true;
    }
    _jspx_tagPool_liferay$1util_html$1top.reuse(_jspx_th_liferay$1util_html$1top_0);
    return false;
  }
}
